pub async fn evaluation<'a, 'b>(
x_fhir_query: &str,
values: Vec<&'a dyn MetaValue>,
config: Arc<Config<'b>>,
) -> Result<String, OperationOutcomeError>where
'a: 'b,Expand description
Evaluates FHIRPath expressions embedded in an x-fhir-query string.
Replaces each FHIRPath expression found in the query with the evaluated
string representation of its result.
Errors
Returns an [OperationOutcomeError] if:
- the embedded
FHIRPathexpression is empty, FHIRPathevaluation fails,- a result value cannot be converted into a string representation.